@@ -54,7 +54,7 @@ void FFTFilter::init(int m)
 {
     setObjectName(tr("FFT") + tr("Filtered"));
     setFilterType(m);
-    d_points = d_n;
+    d_points = d_x.size();
     d_offset = true;
     d_low_freq = 0;
     d_high_freq = 0;
@@ -100,31 +100,31 @@ void FFTFilter::setBand(double lowFreq, double highFreq)
     }
 }
 
-void FFTFilter::calculateOutputData(double *x, double *y)
+void FFTFilter::calculateOutputData(std::vector<double>& x, std::vector<double>& y)
 {
     // interpolate y to even spacing
-    double delta = (d_x[d_n - 1] - d_x[0]) / d_n;
+    double delta = double(d_x.back()- d_x.front()) / d_x.size();
     double xi = d_x[0];
 
-    for (unsigned i = 0, j = 0; j < d_n && xi <= d_x[d_n - 1]; j++) {
+    for (unsigned i = 0, j = 0; j < d_x.size() && xi <= d_x.back(); j++) {
         x[j] = xi;
-        if (i < d_n - 1)
+        if (i < d_x.size() - 1)
             y[j] = ((d_x[i + 1] - xi) * d_y[i] + (xi - d_x[i]) * d_y[i + 1])
                     / (d_x[i + 1] - d_x[i]);
         else
-            y[j] = d_y[d_n - 1];
+            y[j] = d_y.back();
 
         xi += delta;
-        while (i < d_n && xi > d_x[i])
+        while (i < d_x.size() && xi > d_x[i])
             i++;
     }
 
-    double df = 1.0 / (x[d_n - 1] - x[0]);
+    double df = 1.0 / (x.back()- x.front());
 
-    gsl_fft_real_workspace *work = gsl_fft_real_workspace_alloc(d_n);
-    gsl_fft_real_wavetable *real = gsl_fft_real_wavetable_alloc(d_n);
+    gsl_fft_real_workspace *work = gsl_fft_real_workspace_alloc(d_x.size());
+    gsl_fft_real_wavetable *real = gsl_fft_real_wavetable_alloc(d_x.size());
 
-    gsl_fft_real_transform(y, 1, d_n, real, work);
+    gsl_fft_real_transform(y.data(), 1, d_x.size(), real, work);
     gsl_fft_real_wavetable_free(real);
 
     d_explanation = QLocale().toString(d_low_freq) + " ";
@@ -135,19 +135,19 @@ void FFTFilter::calculateOutputData(double *x, double *y)
     switch ((int)d_filter_type) {
     case 1: // low pass
         d_explanation += tr("Low Pass FFT Filter");
-        for (int i = d_n - 1; i >= 0 && ((i + 1) / 2) * df > d_low_freq; i--)
+        for (int i = d_x.size() - 1; i >= 0 && ((i + 1) / 2) * df > d_low_freq; i--)
             y[i] = 0;
         break;
 
     case 2: // high pass
         d_explanation += tr("High Pass FFT Filter");
-        for (unsigned i = 0; i < d_n && ((i + 1) / 2) * df < d_low_freq; i++)
+        for (unsigned i = 0; i < d_x.size() && ((i + 1) / 2) * df < d_low_freq; i++)
             y[i] = 0;
         break;
 
     case 3: // band pass
         d_explanation += tr("Band Pass FFT Filter");
-        for (unsigned i = d_offset ? 1 : 0; i < d_n; i++)
+        for (unsigned i = d_offset ? 1 : 0; i < d_x.size(); i++)
             if ((((i + 1) / 2) * df <= d_low_freq) || (((i + 1) / 2) * df >= d_high_freq))
                 y[i] = 0;
         break;
@@ -158,14 +158,14 @@ void FFTFilter::calculateOutputData(double *x, double *y)
         if (!d_offset)
             y[0] = 0; // substract DC offset
 
-        for (unsigned i = 1; i < d_n; i++)
+        for (unsigned i = 1; i < d_x.size(); i++)
             if ((((i + 1) / 2) * df > d_low_freq) && (((i + 1) / 2) * df < d_high_freq))
                 y[i] = 0;
         break;
     }
 
-    gsl_fft_halfcomplex_wavetable *hc = gsl_fft_halfcomplex_wavetable_alloc(d_n);
-    gsl_fft_halfcomplex_inverse(y, 1, d_n, hc, work);
+    gsl_fft_halfcomplex_wavetable *hc = gsl_fft_halfcomplex_wavetable_alloc(d_x.size());
+    gsl_fft_halfcomplex_inverse(y.data(), 1, d_x.size(), hc, work);
     gsl_fft_halfcomplex_wavetable_free(hc);
     gsl_fft_real_workspace_free(work);
 }
