@@ -45,14 +45,14 @@ class Filter : public QObject
 public:
     Filter(ApplicationWindow *parent, Table *t = 0, QString name = QString());
     Filter(ApplicationWindow *parent, Graph *g = 0, QString name = QString());
-    ~Filter();
-
+    virtual ~Filter() {};
     //! Actually does the job. Should be reimplemented in derived classes.
     virtual bool run();
 
-    virtual void setDataCurve(int curve, double start, double end);
-    bool setDataFromCurve(const QString &curveTitle, Graph *g = 0);
-    bool setDataFromCurve(const QString &curveTitle, double from, double to, Graph *g = 0);
+    virtual void setDataCurve(const int curve, double start, double end);
+    bool setDataFromCurve(const QString &curveTitle, Graph *const g = 0);
+    bool setDataFromCurve(const QString &curveTitle, const double from, const double to,
+                          Graph *const g = 0);
 
     //! Changes the data range if the source curve was already assigned. Provided for convenience.
     void setInterval(double from, double to);
@@ -82,31 +82,29 @@ public:
     virtual QString legendInfo() { return QString(); };
 
     //! Returns the size of the fitted data set
-    int dataSize() { return d_n; };
+    int dataSize() { return d_x.size(); };
 
     bool error() { return d_init_err; };
 
 private:
     void init();
 
-    /**
-     * \brief Sets x and y to the curve points between start and end.
-     *
-     * \returns the number of points within range == size of x and y arrays.
-     * Memory will be allocated with new double[].
-     */
-    int curveData(QwtPlotCurve *c, double start, double end, double **x, double **y);
-    //! Same as curveData, but sorts the points by their x value.
-    int sortedCurveData(QwtPlotCurve *c, double start, double end, double **x, double **y);
-
 protected:
-    virtual bool isDataAcceptable();
+
+    //! returns either sorted or unsorted indices for data in range [start;end]
+    template <typename T>
+    std::vector<size_t> static getIndices(const std::vector<T>& data, const T start, const T end, const bool sorted);
+
+    //! holds either sorted or unsorted indices for further usage
+    std::vector<size_t> d_indices;
+
+    virtual bool isDataAcceptable() const;
 
     //! Adds the result curve to the target output plot window. Creates a hidden table and frees the input data from memory.
-    QwtPlotCurve *addResultCurve(double *x, double *y);
+    QwtPlotCurve *addResultCurve(const std::vector<double> &x, const std::vector<double> &y);
 
     //! Performs checks and returns the index of the source data curve if OK, -1 otherwise
-    int curveIndex(const QString &curveTitle, Graph *g);
+    int curveIndex(const QString &curveTitle, Graph *const g);
 
     //! Output string added to the log pannel of the application
     virtual QString logInfo() { return QString(); };
@@ -115,7 +113,7 @@ protected:
     virtual void output();
 
     //! Calculates the data for the output curve and store it in the X an Y vectors
-    virtual void calculateOutputData(double *X, double *Y)
+    virtual void calculateOutputData(std::vector<double> &X, std::vector<double> &Y)
     {
         Q_UNUSED(X)
         Q_UNUSED(Y)
@@ -127,19 +125,16 @@ protected:
     //! A table source of data
     Table *d_table;
 
-    //! Size of the data arrays
-    unsigned d_n;
-
     //! x data set to be analysed
-    double *d_x;
+    std::vector<double> d_x;
 
     //! y data set to be analysed
-    double *d_y;
+    std::vector<double> d_y;
 
     //! GSL Tolerance, if ever needed...
     double d_tolerance;
 
-    //! Number of result points to de calculated and displayed in the output curve
+    //! Number of result points to be calculated and displayed in the output curve
     int d_points;
 
     //! Color index of the result curve
@@ -170,4 +165,32 @@ protected:
     QString d_explanation;
 };
 
+template <typename T>
+std::vector<size_t> Filter::getIndices(const std::vector<T>& data, const T start, const T end, const bool sorted)
+{
+    std::vector<size_t> result;
+    if (data.empty() || end < start)
+            return result;
+    if (sorted)
+    {
+        std::vector<std::pair<T,size_t>> tData(data.size());
+        size_t ii=0;
+        std::generate(tData.begin(), tData.end(), [&](){ auto pair = std::make_pair(data[ii],ii); ++ii; return pair; });
+        std::sort(tData.begin(),tData.end(),[](const std::pair<T,size_t>& a, std::pair<T,size_t>& b){ return a.first < b.first;});
+        auto first = std::lower_bound(tData.cbegin(),tData.cend(),start,
+                                       [](const std::pair<T,size_t>& a, const T& value){return a.first < value;});
+        auto last  = std::upper_bound(tData.cbegin(),tData.cend(),end,
+                                       [](const T& value, const std::pair<T,size_t>& a){return value < a.first;});
+        std::transform(first,last,std::back_inserter(result),[](const std::pair<T,size_t>& a ){return a.second;});
+    }
+    else
+    {
+        size_t ii = 0;
+        for (auto it = data.cbegin(); data.cend() !=it; ++it)
+        if ((start <= *it)&&(end >= *it))
+            result.push_back(ii++);
+    }
+    return result;
+}
+
 #endif
