@@ -4,11 +4,11 @@
     --------------------------------------------------------------------
     Copyright            : (C) 2006 by Ion Vasilief,
                            Tilman Benkert,
-					  Knut Franke
+                                          Knut Franke
     Email (use @ for *)  : ion_vasilief*yahoo.fr, thzs*gmx.net,
                            knut.franke*gmx.de
     Description          : Notes window class
-                           
+
  ***************************************************************************/
 
 /***************************************************************************
@@ -41,64 +41,66 @@
 #include <QVBoxLayout>
 #include <QPrintDialog>
 
-Note::Note(ScriptingEnv *env, const QString& label, QWidget* parent, const char* name, Qt::WindowFlags f)
-				: MyWidget(label, parent, name, f)
+Note::Note(ScriptingEnv *env, const QString &label, QWidget *parent, const char *name,
+           Qt::WindowFlags f)
+    : MyWidget(label, parent, name, f)
 {
-init(env);	
+    init(env);
 }
 
 void Note::init(ScriptingEnv *env)
 {
-autoExec = false;
-QDateTime dt = QDateTime::currentDateTime ();
-setBirthDate(dt.toString(Qt::LocalDate));
+    autoExec = false;
+    QDateTime dt = QDateTime::currentDateTime();
+    setBirthDate(QLocale().toString(dt));
 
-te = new ScriptEdit(env, this, name());
-te->setContext(this);
-this->setWidget(te);
+    te = new ScriptEdit(env, this, name());
+    te->setContext(this);
+    this->setWidget(te);
 
-setGeometry(0, 0, 500, 200);
-connect(te, SIGNAL(textChanged()), this, SLOT(modifiedNote()));
+    setGeometry(0, 0, 500, 200);
+    connect(te, SIGNAL(textChanged()), this, SLOT(modifiedNote()));
 }
 
 void Note::modifiedNote()
 {
-emit modifiedWindow(this);
+    emit modifiedWindow(this);
 }
 
 QString Note::saveToString(const QString &info)
 {
-QString s= "<note>\n";
-s+= QString(name()) + "\t" + birthDate() + "\n";
-s+= info;
-s+= "WindowLabel\t" + windowLabel() + "\t" + QString::number(captionPolicy()) + "\n";
-s+= "AutoExec\t" + QString(autoExec ? "1" : "0") + "\n";
-s+= "<content>\n"+te->toPlainText().trimmed()+"\n</content>";
-s+="\n</note>\n";
-return s;
+    QString s = "<note>\n";
+    s += QString(name()) + "\t" + birthDate() + "\n";
+    s += info;
+    s += "WindowLabel\t" + windowLabel() + "\t" + QString::number(captionPolicy()) + "\n";
+    s += "AutoExec\t" + QString(autoExec ? "1" : "0") + "\n";
+    s += "<content>\n" + te->toPlainText().trimmed() + "\n</content>";
+    s += "\n</note>\n";
+    return s;
 }
 
-void Note::restore(const QStringList& data)
+void Note::restore(const QStringList &data)
 {
-  QStringList::ConstIterator line = data.begin();
-  QStringList fields;
+    QStringList::ConstIterator line = data.begin();
+    QStringList fields;
 
-  fields = (*line).split("\t");
-  if (fields[0] == "AutoExec"){
-    setAutoexec(fields[1] == "1");
-    line++;
-  }
+    fields = (*line).split("\t");
+    if (fields[0] == "AutoExec") {
+        setAutoexec(fields[1] == "1");
+        line++;
+    }
 
-  if (*line == "<content>") line++;
-  while (line != data.end() && *line != "</content>")
-    te->insertPlainText((*line++)+"\n");
+    if (*line == "<content>")
+        line++;
+    while (line != data.end() && *line != "</content>")
+        te->insertPlainText((*line++) + "\n");
 }
 
 void Note::setAutoexec(bool exec)
 {
-  autoExec = exec;
-  QPalette palette;
-  if (autoExec)
-    palette.setColor(te->backgroundRole(), QColor(255,239,185));
-  te->setPalette(palette);
+    autoExec = exec;
+    QPalette palette;
+    if (autoExec)
+        palette.setColor(te->backgroundRole(), QColor(255, 239, 185));
+    te->setPalette(palette);
 }
