@@ -5,7 +5,7 @@
     --------------------------------------------------------------------
     Copyright            : (C) 2007 Tilman Benkert (thzs*gmx.net)
     Copyright            : (C) 2007 Knut Franke (knut.franke*gmx.de)
-                           (replace * with @ in the email addresses) 
+                           (replace * with @ in the email addresses)
 
  ***************************************************************************/
 
@@ -45,59 +45,54 @@ class AbstractScriptingEngine;
  */
 class Project : public ::future::Folder
 {
-	Q_OBJECT
+    Q_OBJECT
 
-	public:
-		//! MDI subwindow visibility setting
-		enum MdiWindowVisibility
-		{
-			folderOnly,
-			folderAndSubfolders,
-			allMdiWindows
-		};
+public:
+    //! MDI subwindow visibility setting
+    enum MdiWindowVisibility { folderOnly, folderAndSubfolders, allMdiWindows };
 
-	public:
-		Project();
-		~Project();
+public:
+    Project();
+    ~Project();
 
-		//!\name Reimplemented from AbstractAspect
-		//@{
-		virtual const Project *project() const { return this; }
-		virtual Project *project() { return this; }
-		virtual QUndoStack *undoStack() const;
-		virtual QString path() const { return ""; }
+    //!\name Reimplemented from AbstractAspect
+    //@{
+    virtual const Project *project() const { return this; }
+    virtual Project *project() { return this; }
+    virtual QUndoStack *undoStack() const;
+    virtual QString path() const { return ""; }
 #ifndef LEGACY_CODE_0_2_x
-		virtual ProjectWindow *view();
+    virtual ProjectWindow *view();
 #else
-		virtual void *view();
+    virtual void *view();
 #endif
-		virtual QMenu *createContextMenu() const;
-		//@}
-		virtual QMenu *createFolderContextMenu(const ::future::Folder * folder) const;
+    virtual QMenu *createContextMenu() const;
+    //@}
+    virtual QMenu *createFolderContextMenu(const ::future::Folder *folder) const;
 
-		AbstractScriptingEngine * scriptingEngine() const;
+    AbstractScriptingEngine *scriptingEngine() const;
 
-		void setMdiWindowVisibility(MdiWindowVisibility visibility);
-		MdiWindowVisibility mdiWindowVisibility() const;
-		void setFileName(const QString & file_name);
-		QString fileName() const;
-	
-		static ConfigPageWidget * makeConfigPage();
-		static QString configPageLabel();
-	
-		//! \name serialize/deserialize
-		//@{
-		//! Save as XML
-		virtual void save(QXmlStreamWriter *) const;
-		//! Load from XML
-		virtual bool load(XmlStreamReader *);
-		//@}
+    void setMdiWindowVisibility(MdiWindowVisibility visibility);
+    MdiWindowVisibility mdiWindowVisibility() const;
+    void setFileName(const QString &file_name);
+    QString fileName() const;
 
-	private:
-		class Private;
-		Private *d;
+    static ConfigPageWidget *makeConfigPage();
+    static QString configPageLabel();
 
-		friend class ProjectConfigPage;
+    //! \name serialize/deserialize
+    //@{
+    //! Save as XML
+    virtual void save(QXmlStreamWriter *) const;
+    //! Load from XML
+    virtual bool load(XmlStreamReader *);
+    //@}
+
+private:
+    class Private;
+    Private *d;
+
+    friend class ProjectConfigPage;
 };
 
 #endif // ifndef PROJECT_H
