@@ -35,5 +35,10 @@ done
 rm -f Doxyversion
 echo "PROJECT_NUMBER=$version" >Doxyversion
 echo "$version" >doc/version.tex
+
+# update scidavis.appdata.xml
+date=`date +%Y-%m-%d`
+sed -i "s/<release version=.*$/<release version=\"$version\" date=\"$date\">/" scidavis/scidavis.appdata.xml
+
 git commit -a -m "Release $fullversion"
 git tag -a -m "" $fullversion
