@@ -1,7 +1,13 @@
 #!/bin/bash
+if [ $# -eq 0 ]; then
+    project=scidavis
+else
+    project=$1
+fi
+    
 rm results.log
 for i in Dockerfile-*[^~]; do
-    docker build --pull -f $i .
+    docker build --build-arg project=$project --pull -f $i .
     if [ $? -eq 0 ]; then
         echo "$i PASSED" >> results.log
     else
