@@ -30,6 +30,7 @@ trap "fail" 1 2 3 15
 
 # insert test commands here
 cp $here/test/pythonTests/* .
+cp $here/scidavis-logo.png .
 for i in *.py; do
     echo $i
     $here/scidavis/scidavis -l=en -x $i
@@ -38,6 +39,7 @@ done
 
 if [ -z "$TRAVIS" ]; then
     for i in *.png; do
+        if [ $i=scidavis-logo.png ]; then continue; fi
         diff $i $here/test/renderedImages/$i
         if test $? -ne 0; then fail; fi
     done
